summaryrefslogtreecommitdiffstats
path: root/src/loandialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/loandialog.h')
-rw-r--r--src/loandialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/loandialog.h b/src/loandialog.h
index 5cf8354..8c87b80 100644
--- a/src/loandialog.h
+++ b/src/loandialog.h
@@ -40,11 +40,11 @@ public:
/**
* The constructor sets up the dialog.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- LoanDialog(const Data::EntryVec& entries, TQWidget* tqparent, const char* name=0);
- LoanDialog(Data::LoanPtr loan, TQWidget* tqparent, const char* name=0);
+ LoanDialog(const Data::EntryVec& entries, TQWidget* parent, const char* name=0);
+ LoanDialog(Data::LoanPtr loan, TQWidget* parent, const char* name=0);
virtual ~LoanDialog();
KCommand* createCommand();
@@ -40,11 +40,11 @@ public:
* The constructor sets up the dialog.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/